@@ -74,8 +74,6 @@ int main (int argc, char **argv) {
 	/* terminal attributes _before_ we started messing around with ~ECHO */
 	struct termios termOrig;
 
-	BarUiMsg (MSG_NONE, "Welcome to " PACKAGE "!\n");
-
 	/* save terminal attributes, before disabling echoing */
 	BarTermSave (&termOrig);
 
@@ -92,6 +90,9 @@ int main (int argc, char **argv) {
 	BarSettingsInit (&settings);
 	BarSettingsRead (&settings);
 
+	BarUiMsg (MSG_NONE, "Welcome to " PACKAGE "! Press %c for a list of commands.\n",
+			settings.keys[BAR_KS_HELP]);
+
 	/* init fds */
 	FD_ZERO(&readSet);
 	selectFds[0] = fileno (stdin);
